import grpc
import time
import uuid
import os
import sys
import asyncio
import socket
import json
import aiofiles
import aiofiles.os as aioos
import base64
import datetime
import logging
import inspect
from cryptography import x509
from cryptography.hazmat.backends import default_backend
from cryptography.hazmat.primitives import serialization
from cryptography.hazmat.primitives import hashes
from cryptography.hazmat.primitives.asymmetric import ec as asymec
from .dborgproto import dborgproto_pb2_grpc
from .dborgproto import dborgproto_pb2
from hashlib import sha256
import jwt

TLS_KEY_FILENAME = "dashborg-client.key"
TLS_CERT_FILENAME = "dashborg-client.crt"
DEFAULT_PROCNAME = "default"
DEFAULT_ZONENAME = "default"
DASHBORG_HOST = "grpc.api.dashborg.net"
DASHBORG_PORT = 7632
CLIENT_VERSION = "python-0.3.1"

EC_EOF = "EOF"
EC_UNKNOWN = "UNKNOWN"
EC_BADCONNID = "BADCONNID"
EC_ACCACCESS = "ACCACCESS"
EC_NOHANDLER = "NOHANDLER"
EC_UNAVAILABLE = "UNAVAILABLE"

# must be divisible by 3 (for base64 encoding)
BLOB_READ_SIZE = 3 * 340 * 1024

DASHBORG_CERT = """
-----BEGIN CERTIFICATE-----
MIIBxDCCAUmgAwIBAgIFAv2DbD4wCgYIKoZIzj0EAwMwLzEtMCsGA1UEAxMkNWZk
YWYxZDEtYjUyNC00MzYxLWFkY2ItMzI1ZDBlOGFiN2VlMB4XDTIwMDEwMTAwMDAw
MFoXDTMwMDEwMTAwMDAwMFowLzEtMCsGA1UEAxMkNWZkYWYxZDEtYjUyNC00MzYx
LWFkY2ItMzI1ZDBlOGFiN2VlMHYwEAYHKoZIzj0CAQYFK4EEACIDYgAEhsrFNs6I
reL5fWAdQxzNrYRgJdf2zE2aeBj/o28mXR1iQRtAlBY9Jh9zQtZCnypK2MprKvqw
07f0YoquV17gOhumj7LIRhlZ9GANwra6VorRVtVVgKCpTmG8o/ulJ3o4ozUwMzAO
BgNVHQ8BAf8EBAMCB4AwEwYDVR0lBAwwCgYIKwYBBQUHAwIwDAYDVR0TAQH/BAIw
ADAKBggqhkjOPQQDAwNpADBmAjEAtW26nW+AHoa9VQiqmGJ8z/+265YUK6QkkQ+T
276zLFAdfAO+bOVK0MMjzr21v6aLAjEA6LknqHnEh+QDWWIm8vM1Jp/FtiJ0KT//
4qUptLIY0pSijwpt/TAZd4QG8M5IQ+T7
-----END CERTIFICATE-----
"""

_global_client = None
_dblogger = logging.getLogger("dashborg")

def dashts():
    return int(round(time.time()*1000))

def _default_string(*args):
    for s in args:
        if s is not None and s != "":
            return s
    return None

def _parse_int(v):
    try:
        return int(v)
    except:
        return None

class _HandlerVal:
    def __init__(self, fn, proto_hkey):
        self.handler_fn = fn
        self.proto_hkey = proto_hkey

class _StreamControl:
    def __init__(self, panel_name, stream_id, req_id=None, stream_task=None, no_server_cancel=False, has_zero_clients=False):
        self.panel_name = panel_name
        self.stream_id = stream_id
        self.no_server_cancel = no_server_cancel
        self.req_id = req_id
        self.stream_task = stream_task
        self.has_zero_clients = has_zero_clients

class Config:
    def __init__(self, acc_id=None, anon_acc=None, zone_name=None, proc_name=None, proc_tags=None, key_file_name=None, cert_file_name=None, auto_keygen=None, verbose=None, env=None, dashborg_srv_host=None, dashborg_srv_port=None, use_logger=False, allow_backend_calls=False):
        self.acc_id = acc_id
        self.anon_acc = anon_acc
        self.zone_name = zone_name
        self.proc_name = proc_name
        self.proc_tags = proc_tags
        self.key_file_name = key_file_name
        self.cert_file_name = cert_file_name
        self.auto_keygen = auto_keygen
        self.verbose = verbose
        self.env = env
        self.dashborg_srv_host = dashborg_srv_host
        self.dashborg_srv_port = dashborg_srv_port
        self.use_logger = use_logger
        self.allow_backend_calls = allow_backend_calls

    def _set_defaults(self):
        self.acc_id = _default_string(self.acc_id, os.environ.get("DASHBORG_ACCID"))
        self.zone_name = _default_string(self.zone_name, os.environ.get("DASHBORG_ZONE"), DEFAULT_ZONENAME)
        self.env = _default_string(self.env, os.environ.get("DASHBORG_ENV"), "prod")
        if self.env == "prod":
            self.dashborg_srv_host = _default_string(self.dashborg_srv_host, os.environ.get("DASHBORG_PROCHOST"), DASHBORG_HOST)
        else:
            self.dashborg_srv_host = _default_string(self.dashborg_srv_host, os.environ.get("DASHBORG_PROCHOST"), "127.0.0.1")
        if self.dashborg_srv_port is None and os.environ.get("DASHBORG_PROCPORT") is not None:
            env_val = _parse_int(os.environ.get("DASHBORG_PROCPORT"))
            if env_val is not None:
                self.dashborg_srv_port = env_val
        if self.dashborg_srv_port is None:
            self.dashborg_srv_port = DASHBORG_PORT
        cmd_name = None
        if len(sys.argv) > 0:
            cmd_name = sys.argv[0]
        self.proc_name = _default_string(self.proc_name, os.environ.get("DASHBORG_PROCNAME"), cmd_name, DEFAULT_PROCNAME)
        self.key_file_name = _default_string(self.key_file_name, os.environ.get("DASHBORG_KEYFILE"), TLS_KEY_FILENAME)
        self.cert_file_name = _default_string(self.cert_file_name, os.environ.get("DASHBORG_CERTFILE"), TLS_CERT_FILENAME)
        if os.environ.get("DASHBORG_VERBOSE") is not None:
            self.verbose = True
        if os.environ.get("DASHBORG_USELOGGER") is not None:
            self.use_logger = True

    def _load_keys(self):
        if self.auto_keygen:
            self._maybe_make_keys()
        if not os.path.isfile(self.key_file_name):
            raise RuntimeError(f"Dashborg key file does not exist file:{self.key_file_name}")
        if not os.path.isfile(self.cert_file_name):
            raise RuntimeError(f"Dashborg cert file does not exist file:{self.cert_file_name}")
        cert_info = _read_cert_info(self.cert_file_name)
        if self.acc_id is not None and cert_info["acc_id"] != self.acc_id:
            raise RuntimeError(f"Dashborg AccId read from certificate:{cert_info['acc_id']} does not match AccId in config:{self.acc_id}")
        self.acc_id = cert_info["acc_id"]
        print(f"Dashborg KeyFile:{self.key_file_name} CertFile:{self.cert_file_name} SHA256:{cert_info['pk256']}")


    def _maybe_make_keys(self):
        if self.key_file_name is None or self.cert_file_name is None:
            raise RuntimeError("Empty/Invalid Key or Cert filenames")
        has_key = os.path.isfile(self.key_file_name)
        has_cert = os.path.isfile(self.cert_file_name)
        if has_key and has_cert:
            return
        if has_key or has_cert:
            raise RuntimeError(f"Cannot make key:{self.key_file_name} cert:{self.cert_file_name}, one file already exists")
        acc_id = self.acc_id
        if acc_id is None:
            acc_id = str(uuid.uuid4())
        _create_key_pair(self.key_file_name, self.cert_file_name, acc_id)
        print(f"Dashborg created new self-signed keypair key:{self.key_file_name} cert:{self.cert_file_name} for new accountid:{acc_id}")

def _create_key_pair(keyfile, certfile, acc_id):
    private_key = asymec.generate_private_key(asymec.SECP384R1, default_backend())
    public_key = private_key.public_key()
    private_bytes = private_key.private_bytes(encoding=serialization.Encoding.PEM,
                                              format=serialization.PrivateFormat.PKCS8,
                                              encryption_algorithm=serialization.NoEncryption())
    with open(keyfile, "wb") as f:
        f.write(bytes("-----BEGIN EC PARAMETERS-----\n"
                      "BgUrgQQAIg==\n"
                      "-----END EC PARAMETERS-----\n", "utf-8"))
        f.write(private_bytes)
    cert_name = x509.Name([x509.NameAttribute(x509.oid.NameOID.COMMON_NAME, acc_id)])
    builder = x509.CertificateBuilder()
    builder = builder.serial_number(x509.random_serial_number())
    builder = builder.subject_name(cert_name)
    builder = builder.issuer_name(cert_name)
    builder = builder.not_valid_before(datetime.datetime(2020, 1, 1))
    builder = builder.not_valid_after(datetime.datetime(2030, 1, 1))
    builder = builder.public_key(public_key)
    builder = builder.sign(private_key=private_key,
                           algorithm=hashes.SHA256(),
                           backend=default_backend())
    cert_bytes = builder.public_bytes(encoding=serialization.Encoding.PEM)
    with open(certfile, "wb") as f:
        f.write(cert_bytes)


def _read_cert_info(cert_file):
    cert_data = open(cert_file, "rb").read()
    cert = x509.load_pem_x509_certificate(cert_data, default_backend())
    subject = cert.subject
    cns = subject.get_attributes_for_oid(x509.oid.NameOID.COMMON_NAME)
    acc_id = cns[0].value
    pk = cert.public_key()
    pkbytes = pk.public_bytes(serialization.Encoding.DER, serialization.PublicFormat.SubjectPublicKeyInfo)
    pkdigest = sha256(pkbytes)
    pk256_base64 = base64.standard_b64encode(pkdigest.digest()).decode("ascii")
    return {"acc_id": acc_id, "pk256": pk256_base64}

class PanelRequest:
    def __init__(self):
        self.start_time = datetime.datetime.now()
        self.panel_name = None
        self.req_id = None
        self.request_type = None
        self.fe_client_id = None
        self.path = None
        self.err = None
        self.rr_actions = []
        self.is_done = False
        self.data = None
        self.panel_state = None
        self.auth_data = []
        self.auth_impl = False
        self.is_backend_call = False
        self.is_stream = False

    def _set_from_reqmsg(self, req_msg):
        self.panel_name = req_msg.PanelName
        self.req_id = req_msg.ReqId
        self.request_type = req_msg.RequestType
        self.fe_client_id = req_msg.FeClientId
        self.path = req_msg.Path
        self.is_backend_call = req_msg.IsBackendCall

    async def done(self, swallow_error=False):
        if self.is_done:
            return
        self.is_done = True
        if not self.auth_impl and self._is_root_req() and self.err is None:
            self._set_auth_data({"type": "noauth", "role": "user"})
        if self.is_stream:
            _global_client._handle_stream_close(self, cancel_task=False, from_server=False)
        try:
            await _global_client._send_request_response(self, True)
        except BaseException as e:
            if swallow_error:
                _log_info(f"Dashborg error in done() sending request response {type(e)}:{e}")
            else:
                raise e

    def _append_rr(self, rr):
        self.rr_actions.append(rr)

    def _is_root_req(self):
        return self.request_type == "handler" and self.panel_name is not None and self.path == "/"

    async def flush(self):
        if self.is_done:
            raise RuntimeError("Cannot flush(), PanelRequest is already done")
        try:
            num_stream_clients = await _global_client._send_request_response(self, False)
            if self.is_stream and num_stream_clients == 0:
                _global_client._handle_stream_zero_clients(self)
        except BaseException as e:
            _global_client._handle_stream_close(self, cancel_task=True, from_server=True)
            raise e

    def _is_authenticated(self):
        raw_auth = self.auth_data
        return raw_auth is not None and len(raw_auth) > 0

    def check_auth(self, *, none=False, password=None, dashborg=False, simplelogin=None, simplejwt=None):
        self.auth_impl = True
        if self._is_authenticated():
            return True
        # check auths
        if none:
            self._set_auth_data({"type": "noauth", "role": "user"})
            return
        challengedata = self.data.get("challengedata") if type(self.data) is dict else None
        if password is not None:
            if challengedata is not None and challengedata.get("password") == password:
                self._set_auth_data({"type": "password", "role": "user"})
                return True
        loginresp = None
        loginresp_err = None
        if simplelogin is not None:
            if challengedata is not None:
                try:
                    loginresp = simplelogin(challengedata.get("user"), challengedata.get("password"))
                except RuntimeError as e:
                    loginresp_err = str(e)
                except Exception as e:
                    loginresp_err = repr(e)
                if loginresp is not None and loginresp.get("login_ok"):
                    role = loginresp.get("role") or "user"
                    aa = {"type": "login", "role": role}
                    if loginresp.get("id") is not None:
                        aa["id"] = loginresp.get("id")
                    self._set_auth_data(aa)
                    return True
        if simplejwt is not None:
            if not isinstance(simplejwt, AuthSimpleJwt):
                raise RuntimeError("simplejwt parameter must be instance of AuthSimpleJwt")
            jwtparam = _get_pstate_urlparam(self, simplejwt.param_name)
            if jwtparam is not None:
                try:
                    aa = simplejwt._parse_jwt_to_auth_atom(jwtparam)
                    self._set_auth_data(aa)
                    ch = {"allowedauth": "removeparam", "removeparam": simplejwt.param_name}
                    self._append_panelauth_challenge(ch)
                    return True
                except RuntimeError as e:
                    ch = {"allowedauth": "message", "removeparam": simplejwt.param_name}
                    ch["messagetitle"] = "External Sign In Error"
                    ch["message"] = str(e)
                    self._append_panelauth_challenge(ch)
                except Exception as e:
                    ch = {"allowedauth": "message", "removeparam": simplejwt.param_name}
                    ch["messagetitle"] = "External Sign In Error"
                    ch["message"] = f"Error validating JWT token '{simplejwt.param_name}': {str(e)}"
                    self._append_panelauth_challenge(ch)
        
        # add challenges
        if dashborg:
            self._append_panelauth_challenge({"allowedauth": "dashborg"})
        if password is not None:
            ch = {"allowedauth": "challenge"}
            ch["challengefields"] = [{"label": "Panel Password", "name": "password", "type": "password"}]
            if challengedata is not None and challengedata.get("submitted") == "1":
                chpw = challengedata.get("password")
                if chpw is None or chpw == "":
                    ch["challengeerror"] = "Password cannot be blank"
                else:
                    ch["challengeerror"] = "Invalid Password"
            self._append_panelauth_challenge(ch)
        if simplelogin is not None:
            ch = {"allowedauth": "challenge"}
            ch["challengefields"] = \
                    [{"label": "User", "name": "user", "type": "text"},
                     {"label": "Password", "name": "password", "type": "password"}]
            if challengedata is not None and challengedata.get("submitted") == "1":  # use loginresp from above
                if loginresp_err is not None:
                    ch["challengeerror"] = loginresp_err
                else:
                    ch["challengeerror"] = "Invalid User/Password"
            self._append_panelauth_challenge(ch)
        if simplejwt is not None:
            ch = {"allowedauth": "simplejwt", "removeparam": simplejwt.param_name}
            self._append_panelauth_challenge(ch)
                
        return False

    def _get_auth_atom(self, auth_type):
        for aa in self.auth_data:
            if aa.get("type") == auth_type:
                return aa
        return None

    def _set_auth_data(self, auth_atom):
        if auth_atom.get("scope") is None:
            auth_atom["scope"] = f"panel:{_global_client.config.zone_name}:{self.panel_name}"
        if auth_atom.get("ts") is None:
            auth_atom["ts"] = dashts() + (24 * 60 * 60 * 1000)
        if auth_atom.get("type") is None:
            raise RuntimeError("Dashborg Invalid AuthAtom, no Type specified")
        json_data = json.dumps(auth_atom)
        rr_action = dborgproto_pb2.RRAction(Ts=dashts(), ActionType="panelauth", JsonData=json_data)
        self._append_rr(rr_action)
        return
        
    def _append_panelauth_challenge(self, challenge):
        json_data = json.dumps(challenge)
        rr_action = dborgproto_pb2.RRAction(Ts=dashts(), ActionType="panelauthchallenge", JsonData=json_data)
        self._append_rr(rr_action)
        pass

    def set_data(self, path, data):
        if self.is_done:
            raise RuntimeError(f"Cannot call set_data(), path={path}, PanelRequest is already done")
        json_data = json.dumps(data)
        rr_action = dborgproto_pb2.RRAction(Ts=dashts(), ActionType="setdata", Selector=path, JsonData=json_data)
        self._append_rr(rr_action)
        return

    async def set_blob_data(self, path, mime_type, readable):
        if self.is_done:
            raise RuntimeError(f"Cannot call set_blob_data(), path={path} mime-type={mime_type}, PanelRequest is already done")
        # validate mime-type
        first = True
        while True:
            buffer = readable.read(BLOB_READ_SIZE)
            if inspect.isawaitable(buffer):
                buffer = await buffer
            if len(buffer) == 0:
                break
            rr_action = dborgproto_pb2.RRAction(Ts=dashts(), Selector=path, BlobBytes=buffer)
            if first:
                rr_action.ActionType = "blob"
                rr_action.BlobMimeType = mime_type
                first = False
            else:
                rr_action.ActionType = "blobext"
            self._append_rr(rr_action)
            await self.flush()
        return

    async def set_blob_data_from_file(self, path, mime_type, file_name):
        if self.is_done:
            raise RuntimeError(f"Cannot call set_blob_data_from_file(), PanelRequest is already done")
        fd = await aiofiles.open(file_name, "rb")
        await self.set_blob_data(path, mime_type, fd)
        return

    def set_html(self, html):
        if self.is_done:
            raise RuntimeError(f"Cannot call set_html(), PanelRequest is already done")
        rr_action = dborgproto_pb2.RRAction(Ts=dashts(), ActionType="html", Html=html)
        self._append_rr(rr_action)
        return

    async def set_html_from_file(self, file_name):
        if self.is_done:
            raise RuntimeError(f"Cannot call set_html(), PanelRequest is already done")
        fd = await aiofiles.open(file_name, "r")
        html = await fd.read()
        self.set_html(html)
        return

    def invalidate_data(self, path):
        if self.is_done:
            raise RuntimeError(f"Cannot call invalidate_data(), path={path}, PanelRequest is already done")
        rr_action = dborgproto_pb2.RRAction(Ts=dashts(), ActionType="invalidate", Selector=path)
        self._append_rr(rr_action)
        return

    async def start_stream(self, stream_id, control_path, stream_fn=None, no_server_cancel=False):
        # todo - validate params
        if stream_id is None:
            stream_id = str(uuid.uuid4())
        if self.is_done:
            raise RuntimeError(f"Cannot call start_stream(), PanelRequest is already done")
        if self.is_stream:
            raise RuntimeError(f"Cannot call start_stream(), PanelRequest is already streaming")
        if self.fe_client_id is None or self.fe_client_id == "":
            raise RuntimeError(f"No fe_client_id, client does not support streaming")
        stream_req_id, should_start = await _global_client._start_stream(self.panel_name, stream_id, self.fe_client_id, no_server_cancel=no_server_cancel)
        json_data = json.dumps({"reqid": stream_req_id, "controlpath": control_path})
        rr_action = dborgproto_pb2.RRAction(Ts=dashts(), ActionType="streamopen", JsonData=json_data)
        self._append_rr(rr_action)
        await self.flush()
        if should_start:
            stream_req = PanelRequest()
            stream_req.panel_name = self.panel_name
            stream_req.req_id = stream_req_id
            stream_req.request_type = "stream"
            stream_req.path = stream_id
            stream_req.is_stream = True
            async def cancel_wrap():
                try:
                    if stream_fn is not None:
                        await stream_fn(stream_req)
                except asyncio.CancelledError:
                    _log_info(f"Dashborg stream reqid:{stream_req.req_id} canceled")
                except BaseException as e:
                    _log_error(f"Dashborg uncaught stream_fn exception {type(e)}:{e}")
                    raise e
                finally:
                    await stream_req.done(swallow_error=True)
            stream_task = asyncio.create_task(cancel_wrap())
            _global_client._set_stream_task(self.panel_name, stream_id, stream_task)
        return

def _make_handler_key(req_msg):
    htype = None
    if req_msg.RequestType == "data":
        htype = "data"
    elif req_msg.RequestType == "handler":
        htype = "handler"
    else:
        raise RuntimeError(f"Invalid RequestMessage.RequestType [{req_msg.RequestType}]")
    path = req_msg.Path
    if path == "":
        path = None
    return (req_msg.PanelName, htype, path)

class Client:
    def __init__(self, config):
        self.cvar = asyncio.Condition()
        self.start_ts = dashts()
        self.proc_run_id = str(uuid.uuid4())
        self.handler_map = {}    # (panel_name, handler_type, path) -> _HandlerVal
        self.stream_map = {}     # (panel_name, stream_id) -> _StreamControl
        self.stream_key_map = {} # req_id -> (panel_name, stream_id)
        self.conn_id = None
        self.config = config
        self.conn = None
        self.db_service = None

    async def _wait_for_clear(self, wait_time=1.0):
        self.conn.close()
        await asyncio.sleep(wait_time)

    async def _connect_grpc(self):
        if self.conn is not None:
            await self.conn.close()
        if self.config.verbose:
            print(f"Dashborg Connect gRPC ({self.config.dashborg_srv_host})")
        addr = self.config.dashborg_srv_host + ":" + str(self.config.dashborg_srv_port)
        # todo backoff config
        # todo connect params
        private_key = open(self.config.key_file_name, "rb").read()
        cert = open(self.config.cert_file_name, "rb").read()
        servercert = bytes(DASHBORG_CERT, "utf-8")
        creds = grpc.ssl_channel_credentials(root_certificates=servercert, private_key=private_key, certificate_chain=cert)
        options = (("grpc.ssl_target_name_override", "5fdaf1d1-b524-4361-adcb-325d0e8ab7ee"),
                   ("grpc.keepalive_time_ms", 5000),
                   ("grpc.keepalive_permit_without_calls", 1),
                   ("grpc.max_reconnect_backoff_ms", 60000),
                   ("grpc.min_reconnect_backoff_ms", 1000),
                   ("grpc.initial_reconnect_backoff_ms", 1000),
                   ("grpc.server_handshake_timeout_ms", 10000),
                   ("grpc.max_receive_message_length", 10000000))
        # "grpc.enable_retries"
        self.conn = grpc.aio.secure_channel(target=addr, credentials=creds, options=options)
        self.db_service = dborgproto_pb2_grpc.DashborgServiceStub(self.conn)

    def _get_proc_handlers(self):
        rtn = []
        for k in self.handler_map.keys():
            h = self.handler_map.get(k)
            rtn.append(h.proto_hkey)
        return rtn

    async def _send_proc_message(self):
        proc_msg = dborgproto_pb2.ProcMessage()
        proc_msg.Ts = dashts()
        proc_msg.ProcRunId = self.proc_run_id
        proc_msg.AccId = self.config.acc_id
        proc_msg.ZoneName = self.config.zone_name
        proc_msg.AnonAcc = self.config.anon_acc
        proc_msg.ProcName = self.config.proc_name
        if self.config.proc_tags is not None:
            for k in self.config.proc_tags.keys():
                proc_msg.ProcTags[k] = self.config.proc_tags[k]
        proc_msg.HostData["HostName"] = socket.gethostname()
        proc_msg.HostData["Pid"] = str(os.getpid())
        proc_msg.StartTs = self.start_ts
        proc_msg.Handlers.extend(self._get_proc_handlers())
        proc_msg.ClientVersion = CLIENT_VERSION
        try:
            rtn = await self.db_service.Proc(proc_msg)
            if rtn.Success:
                self.conn_id = rtn.ConnId
                _log_info_config(self.config, f"Dashborg ProcClient connected connid:{self.conn_id}")
            else:
                _log_error(f"Dashborg Error calling Proc(), err:{rtn.Err} code:{rtn.ErrCode}")
                self.conn_id = None
        except grpc.RpcError as e:
            if e.code() == grpc.StatusCode.UNAVAILABLE:
                _log_error(f"Dashborg service unavailable: {e.details()}")
            else:
                _log_error(f"Dashborg Error calling Proc() {e}")
            self.conn_id = None

    async def _run_request_stream_loop(self):
        needs_wait = False
        num_waits = 0
        while True:
            s = self.conn.get_state()
            if s == grpc.ChannelConnectivity.SHUTDOWN:
                _log_info(f"Dashborg stopping request loop, channel shutdown")
                return
            if s == grpc.ChannelConnectivity.CONNECTING or s == grpc.ChannelConnectivity.TRANSIENT_FAILURE:
                _log_info(f"Dashborg waiting for gRPC connection")
                await asyncio.sleep(1)
                needs_wait = False
                continue
            if needs_wait:
                _log_info(f"Dashborg run_request_stream_loop needs_wait")
                await asyncio.sleep(1)
            if self.conn_id == None:
                await self._send_proc_message()
                needs_wait = (self.conn_id is None)
                continue
            ec = await self._run_request_stream()
            _log_info(f"Dashborg run_request_stream finished ec:{ec}")
            if ec == EC_BADCONNID:
                self.conn_id = None
                continue
            needs_wait = True

    async def _dispatch_request(self, req_msg):
        if req_msg.Err is not None and req_msg.Err != "":
            _log_info(f"Dashborg dispatch_request got error request err:{req_msg.Err}")
            return
        _log_info(f"Dashborg gRPC got request panel={req_msg.PanelName}, type={req_msg.RequestType}, path={req_msg.Path}")
        preq = PanelRequest()
        preq._set_from_reqmsg(req_msg)
        if req_msg.RequestType == "streamclose":
            self._handle_stream_close(preq, cancel_task=True, from_server=True)
            return # no response for streamclose
        hkey = _make_handler_key(req_msg)
        hval = self.handler_map.get(hkey)
        if hval == None:
            preq.err = f"No Handler found for panel={req_msg.PanelName}, type={req_msg.RequestType}, path={req_msg.Path}"
            await preq.done()
            return
        try:
            if req_msg.JsonData is not None and req_msg.JsonData != "":
                data = json.loads(req_msg.JsonData)
                preq.data = data
            if req_msg.PanelStateData is not None and req_msg.PanelStateData != "":
                panel_state = json.loads(req_msg.PanelStateData)
                preq.panel_state = panel_state
            if req_msg.AuthData is not None and req_msg.AuthData != "":
                auth = json.loads(req_msg.AuthData)
                preq.auth_data = auth
            if not preq._is_root_req():
                if not preq._is_authenticated():
                    preq.err = "Request is not authenticated"
                    await preq.done()
                    return
        except json.JSONDecodeError as e:
            _log_info(f"Cannot json.loads request data err:{e}")
        try:
            rtnval = None
            if inspect.iscoroutinefunction(hval.handler_fn):
                timeout_val = req_msg.TimeoutMs / 1000.0 if req_msg.TimeoutMs > 0 else None
                if timeout_val is None or timeout_val > 60:
                    timeout_val = 60
                rtnval = await asyncio.wait_for(hval.handler_fn(preq), timeout_val)
            else:
                rtnval = hval.handler_fn(preq)
            if req_msg.RequestType == "data":
                rr_action = dborgproto_pb2.RRAction(Ts=dashts(), ActionType="setdata", JsonData=json.dumps(rtnval))
                preq._append_rr(rr_action)
        except Exception as e:
            preq.err = repr(e);
        finally:
            await preq.done(swallow_error=True)

    async def _run_request_stream(self):
        try:
            _log_info("Dashborg gRPC RequestStream starting")
            stream_msg = dborgproto_pb2.RequestStreamMessage(Ts=dashts())
            conn_meta = (("dashborg-connid", self.conn_id),)
            msgs = self.db_service.RequestStream(stream_msg, metadata=conn_meta)
            ending_ec = None
            req_counter = 0
            async for msg in msgs:
                if msg.ErrCode == dborgproto_pb2.EC_BADCONNID:
                    ending_ec = EC_BADCONNID
                    _log_info("Dashborg gRPC RequestStream BADCONNID")
                    break
                if msg.Err is not None and msg.Err != "":
                    ending_ec = EC_UNKNOWN
                    _log_info(f"Dashborg gRPC RequestStrem error:{msg.Err} code:{msg.ErrCode}")
                    break
                req_counter += 1
                asyncio.create_task(self._dispatch_request(msg))
            if ending_ec is None:
                _log_info("Dashborg gRPC RequestStream end of iteration")
                return EC_EOF
            return ending_ec
        except grpc.RpcError as e:
            if e.code() == grpc.StatusCode.UNAVAILABLE:
                return EC_UNAVAILABLE
            _log_info(f"Dashborg gRPC error {e}")
            return EC_UNKNOWN
        finally:
            _log_info("Dashborg gRPC RequestStream done")

    async def _register_handler(self, proto_hkey, handler_fn):
        path = None if proto_hkey.Path == "" else proto_hkey.Path
        hkey = (proto_hkey.PanelName, proto_hkey.HandlerType, path)
        self.handler_map[hkey] = _HandlerVal(handler_fn, proto_hkey)
        if self.conn_id is None:
            return
        msg = dborgproto_pb2.RegisterHandlerMessage(Ts=dashts())
        msg.Handlers.append(proto_hkey)
        conn_meta = (("dashborg-connid", self.conn_id),)
        try:
            resp = await self.db_service.RegisterHandler(msg, metadata=conn_meta)
            if resp.Err is not None and resp.Err != "":
                _log_error(f"Dashborg RegisterHandler error:{resp.Err} code:{resp.ErrCode}")
                return
            _log_info(f"Dashborg RegisterHandler Success {hkey}")
        except grpc.RpcError as e:
            _log_error(f"Dashborg RegisterHandler Error-rpc: {e}")

    async def _send_request_response(self, req, done):
        if req.is_stream and _global_client._stream_has_zero_clients(req.req_id):
            req.rr_actions = []
            return 0
        if self.conn_id is None:
            raise RuntimeError("No Active ConnId for RequestResponse")
        msg = dborgproto_pb2.SendResponseMessage(
            Ts=dashts(),
            ReqId=req.req_id,
            RequestType=req.request_type,
            PanelName=req.panel_name,
            FeClientId=req.fe_client_id,
            ResponseDone=done,
            Err=req.err)
        msg.Actions.extend(req.rr_actions)
        req.rr_actions = []
        conn_meta = (("dashborg-connid", self.conn_id),)
        resp = await self.db_service.SendResponse(msg, metadata=conn_meta)
        if resp.Err is not None and resp.Err != "":
            raise RuntimeError(f"Dashborg SendResponse error:{resp.Err}")
        return resp.NumStreamClients

    async def _reflect_zone(self):
        m = dborgproto_pb2.ReflectZoneMessage(Ts=dashts())
        conn_meta = (("dashborg-connid", self.conn_id),)
        resp = await self.db_service.ReflectZone(m, metadata=conn_meta)
        if resp.Err is not None and resp.Err != "":
            raise RuntimeError(f"Error calling reflect_zone err:{resp.Err}")
        if not resp.Success:
            raise RuntimeError(f"Error calling reflect_zone")
        rtn = None
        if resp.JsonData is not None and resp.JsonData != "":
            rtn = json.loads(resp.JsonData)
        return rtn

    async def _backend_push(self, panel_name, path):
        m = dborgproto_pb2.BackendPushMessage(Ts=dashts(), PanelName=panel_name, Path=path)
        conn_meta = (("dashborg-connid", self.conn_id),)
        resp = await self.db_service.BackendPush(m, metadata=conn_meta)
        if resp.Err is not None and resp.Err != "":
            raise RuntimeError(f"Error calling backend_push err:{resp.Err}")
        if not resp.Success:
            raise RuntimeError(f"Error calling backend_push")
        return

    async def _call_data_handler(self, panel_name, path, data):
        json_data = None
        if data is not None:
            json_data = json.dumps(data)
        m = dborgproto_pb2.CallDataHandlerMessage(
            Ts=dashts(),
            PanelName=panel_name,
            Path=path,
            JsonData=json_data)
        conn_meta = (("dashborg-connid", self.conn_id),)
        resp = await self.db_service.CallDataHandler(m, metadata=conn_meta)
        if resp.Err is not None and resp.Err != "":
            raise RuntimeError(f"Error calling call_data_handler err:{resp.Err}")
        if not resp.Success:
            raise RuntimeError(f"Error calling call_data_handler")
        rtn = None
        if resp.JsonData is not None and resp.JsonData != "":
            rtn = json.loads(resp.JsonData)
        return rtn

    def _start_bare_stream(self, panel_name, stream_id):
        skey = (panel_name, stream_id)
        sc = self.stream_map.get(skey)
        if sc is not None:
            raise RuntimeError(f"Stream already exists")
        sc = _StreamControl(panel_name, stream_id, req_id=str(uuid.uuid4()), no_server_cancel=True, has_zero_clients=True)
        self.stream_key_map[sc.req_id] = skey
        self.stream_map[skey] = sc
        return sc.req_id

    # returns (stream_req_id, should_start)
    async def _start_stream(self, panel_name, stream_id, fe_client_id, no_server_cancel=False):
        skey = (panel_name, stream_id)
        sc = self.stream_map.get(skey)
        if sc is None:
            sc = _StreamControl(panel_name, stream_id, no_server_cancel=no_server_cancel)
        m = dborgproto_pb2.StartStreamMessage(Ts=dashts(), PanelName=panel_name, FeClientId=fe_client_id)
        if sc.req_id is not None:
            m.ExistingReqId = sc.req_id
        conn_meta = (("dashborg-connid", self.conn_id),)
        resp = await self.db_service.StartStream(m, metadata=conn_meta)
        if resp.Err is not None and resp.Err != "":
            raise RuntimeError(f"Error starting stream err:{resp.Err}")
        if not resp.Success:
            raise RuntimeError(f"Error starting stream")
        if sc.req_id is not None and sc.req_id != resp.ReqId:
            raise RuntimeError(f"Error starting stream, returned req_id:{resp.ReqId} does not match existing req_id:{sc.req_id}")
        sc.has_zero_clients = False
        if sc.req_id is not None:
            return sc.req_id, False
        sc.req_id = resp.ReqId
        self.stream_map[skey] = sc
        self.stream_key_map[sc.req_id] = skey
        return resp.ReqId, True

    def _set_stream_task(self, panel_name, stream_id, stream_task):
        skey = (panel_name, stream_id)
        sc = self.stream_map.get(skey)
        if sc is None:
            return
        sc.stream_task = stream_task
        return

    def _handle_stream_close(self, preq, cancel_task=True, from_server=False):
        skey = self.stream_key_map.get(preq.req_id)
        if skey is None:
            return
        sc = self.stream_map.get(skey)
        if sc is None:
            return
        if from_server and sc.no_server_cancel:
            sc.has_zero_clients = True
            return
        self._delete_and_cancel_stream(preq.req_id, cancel_task=cancel_task)
        return

    def _delete_and_cancel_stream(self, req_id, cancel_task=True):
        skey = self.stream_key_map.get(req_id)
        if skey is None:
            return
        sc = self.stream_map.get(skey)
        if sc is None:
            return
        if cancel_task and sc.stream_task is not None:
            sc.stream_task.cancel()
        self.stream_key_map.pop(req_id)
        self.stream_map.pop(skey)

    def _handle_stream_zero_clients(self, preq):
        skey = self.stream_key_map.get(preq.req_id)
        if skey is None:
            return
        sc = self.stream_map.get(skey)
        if sc is None:
            return
        sc.has_zero_clients = True
        if sc.no_server_cancel:
            return
        self._delete_and_cancel_stream(preq.req_id, cancel_task=True)

    def _stream_has_zero_clients(self, req_id):
        skey = self.stream_key_map.get(req_id)
        if skey is None:
            return True
        sc = self.stream_map.get(skey)
        if sc is None:
            return True
        return sc.has_zero_clients
        

async def start_proc_client(config):
    config._set_defaults()
    config._load_keys()
    client = Client(config)
    await client._connect_grpc()
    print(f"Dashborg Initialized Client AccId:{config.acc_id} Zone:{config.zone_name} ProcName:{config.proc_name} ProcRunId:{client.proc_run_id}")
    await client._send_proc_message()
    global _global_client
    _global_client = client
    asyncio.create_task(client._run_request_stream_loop())
    return

async def _wait_for_clear(wait_time=1.0):
    if _global_client is not None:
        await _global_client._wait_for_clear(wait_time)

def panel_link(panel_name):
    acc_id = _global_client.config.acc_id
    zone_name = _global_client.config.zone_name
    if _global_client.config.env != "prod":
        return f"http://acc-{acc_id}.console.dashborg.localdev:8080/zone/{zone_name}/{panel_name}"
    return f"https://acc-{acc_id}.console.dashborg.net/zone/{zone_name}/{panel_name}"

async def register_data_handler(panel_name, path, handler_fn):
    hkey = dborgproto_pb2.HandlerKey(PanelName=panel_name, HandlerType="data", Path=path)
    await _global_client._register_handler(hkey, handler_fn)

async def register_panel_handler(panel_name, path, handler_fn):
    hkey = dborgproto_pb2.HandlerKey(PanelName=panel_name, HandlerType="handler", Path=path)
    await _global_client._register_handler(hkey, handler_fn)
    if path == "/":
        print(f"Dashborg Panel Link [{panel_name}]: {panel_link(panel_name)}")

def _log_info(*args):
    if _global_client is None:
        return
    if _global_client.config.use_logger:
        _dblogger.info(*args)
    elif _global_client.config.verbose:
        print(*args)

def _log_info_config(config, *args):
    if config is None:
        return
    if config.use_logger:
        _dblogger.info(*args)
    elif config.verbose:
        print(*args)

def _log_error(*args):
    if _global_client is not None and _global_client.config.use_logger:
        _dblogger.error(*args)
    else:
        print(args)

async def reflect_zone():
    return await _global_client._reflect_zone()

async def backend_push(panel_name, path):
    return await _global_client._backend_push(panel_name, path)

async def call_data_handler(panel_name, path, data):
    return await _global_client._call_data_handler(panel_name, path, data)

def start_bare_stream(panel_name, stream_id):
    if stream_id is None:
        raise RuntimeError("Invalid stream_id")
    stream_req_id = _global_client._start_bare_stream(panel_name, stream_id)
    stream_req = PanelRequest()
    stream_req.panel_name = panel_name
    stream_req.req_id = stream_req_id
    stream_req.request_type = "stream"
    stream_req.path = stream_id
    stream_req.is_stream = True
    return stream_req


class AuthSimpleJwt:
    def __init__(self, *, issuer=None, param_name=None, audience=None, signing_key=None):
        if issuer is None:
            raise RuntimeError("AuthSimpleJwt must have an issuer")
        if param_name is None:
            raise RuntimeError("AuthSimpleJwt must have a param_name")
        if signing_key is None:
            raise RuntimeError("AuthSimpleJwt must have a signing_key")
        self.issuer = issuer
        self.param_name = param_name
        self.audience = audience
        self.signing_key = signing_key

    def make_jwt(self, id_, valid_for_sec=15*60):
        claims = {}
        claims["exp"] = int(time.time()) + valid_for_sec
        claims["iat"] = int(time.time()) - 5
        claims["iss"] = self.issuer
        if self.audience is not None:
            claims["aud"] = self.audience
        claims["sub"] = id_
        return jwt.encode(claims, self.signing_key)

    def _parse_jwt_to_auth_atom(self, jwtparam):
        token = jwt.decode(jwtparam, self.signing_key, algorithms=["HS256"])
        if token is None:
            raise RuntimeError(f"Error Parsing JWT token '{self.param_name}'")
        if token["iss"] != self.issuer:
            raise RuntimeError(f"Wrong issuer for JWT token '{self.param_name}' got[{token['iss']}] expected[{self.issuer}]")
        if self.audience is not None:
            token_aud = token.get("aud")
            if self.audience != token_aud:
                raise RuntimeError(f"Wrong audience for JWT token '{self.param_name}' got[{token_aud}] expected[{self.audience}]")
        if token.get("sub") is None:
            raise RuntimeError(f"JWT Token '{self.params_name}' does not contain a subject")
        role = token.get("role") or "user"
        return {"type": "simplejwt", "id": token.get("sub"), "role": role}

        
def _get_pstate_urlparam(req, param_name):
    if req is None or req.panel_state is None or req.panel_state.get("urlparams") is None:
        return None
    urlparams = req.panel_state.get("urlparams")
    if not isinstance(urlparams, dict):
        return None
    return urlparams.get(param_name)
    



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import dborgproto_pb2 as dborgproto__pb2


class DashborgServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Proc = channel.unary_unary(
                '/dashborg.rpc1.DashborgService/Proc',
                request_serializer=dborgproto__pb2.ProcMessage.SerializeToString,
                response_deserializer=dborgproto__pb2.ProcResponse.FromString,
                )
        self.SendResponse = channel.unary_unary(
                '/dashborg.rpc1.DashborgService/SendResponse',
                request_serializer=dborgproto__pb2.SendResponseMessage.SerializeToString,
                response_deserializer=dborgproto__pb2.SendResponseResponse.FromString,
                )
        self.RegisterHandler = channel.unary_unary(
                '/dashborg.rpc1.DashborgService/RegisterHandler',
                request_serializer=dborgproto__pb2.RegisterHandlerMessage.SerializeToString,
                response_deserializer=dborgproto__pb2.RegisterHandlerResponse.FromString,
                )
        self.StartStream = channel.unary_unary(
                '/dashborg.rpc1.DashborgService/StartStream',
                request_serializer=dborgproto__pb2.StartStreamMessage.SerializeToString,
                response_deserializer=dborgproto__pb2.StartStreamResponse.FromString,
                )
        self.ReflectZone = channel.unary_unary(
                '/dashborg.rpc1.DashborgService/ReflectZone',
                request_serializer=dborgproto__pb2.ReflectZoneMessage.SerializeToString,
                response_deserializer=dborgproto__pb2.ReflectZoneResponse.FromString,
                )
        self.CallDataHandler = channel.unary_unary(
                '/dashborg.rpc1.DashborgService/CallDataHandler',
                request_serializer=dborgproto__pb2.CallDataHandlerMessage.SerializeToString,
                response_deserializer=dborgproto__pb2.CallDataHandlerResponse.FromString,
                )
        self.BackendPush = channel.unary_unary(
                '/dashborg.rpc1.DashborgService/BackendPush',
                request_serializer=dborgproto__pb2.BackendPushMessage.SerializeToString,
                response_deserializer=dborgproto__pb2.BackendPushResponse.FromString,
                )
        self.RequestStream = channel.unary_stream(
                '/dashborg.rpc1.DashborgService/RequestStream',
                request_serializer=dborgproto__pb2.RequestStreamMessage.SerializeToString,
                response_deserializer=dborgproto__pb2.RequestMessage.FromString,
                )


class DashborgServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Proc(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendResponse(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterHandler(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartStream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReflectZone(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CallDataHandler(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BackendPush(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RequestStream(self, request, context):
        """this is backwards since the server sends requests, and the client responds to them
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DashborgServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Proc': grpc.unary_unary_rpc_method_handler(
                    servicer.Proc,
                    request_deserializer=dborgproto__pb2.ProcMessage.FromString,
                    response_serializer=dborgproto__pb2.ProcResponse.SerializeToString,
            ),
            'SendResponse': grpc.unary_unary_rpc_method_handler(
                    servicer.SendResponse,
                    request_deserializer=dborgproto__pb2.SendResponseMessage.FromString,
                    response_serializer=dborgproto__pb2.SendResponseResponse.SerializeToString,
            ),
            'RegisterHandler': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterHandler,
                    request_deserializer=dborgproto__pb2.RegisterHandlerMessage.FromString,
                    response_serializer=dborgproto__pb2.RegisterHandlerResponse.SerializeToString,
            ),
            'StartStream': grpc.unary_unary_rpc_method_handler(
                    servicer.StartStream,
                    request_deserializer=dborgproto__pb2.StartStreamMessage.FromString,
                    response_serializer=dborgproto__pb2.StartStreamResponse.SerializeToString,
            ),
            'ReflectZone': grpc.unary_unary_rpc_method_handler(
                    servicer.ReflectZone,
                    request_deserializer=dborgproto__pb2.ReflectZoneMessage.FromString,
                    response_serializer=dborgproto__pb2.ReflectZoneResponse.SerializeToString,
            ),
            'CallDataHandler': grpc.unary_unary_rpc_method_handler(
                    servicer.CallDataHandler,
                    request_deserializer=dborgproto__pb2.CallDataHandlerMessage.FromString,
                    response_serializer=dborgproto__pb2.CallDataHandlerResponse.SerializeToString,
            ),
            'BackendPush': grpc.unary_unary_rpc_method_handler(
                    servicer.BackendPush,
                    request_deserializer=dborgproto__pb2.BackendPushMessage.FromString,
                    response_serializer=dborgproto__pb2.BackendPushResponse.SerializeToString,
            ),
            'RequestStream': grpc.unary_stream_rpc_method_handler(
                    servicer.RequestStream,
                    request_deserializer=dborgproto__pb2.RequestStreamMessage.FromString,
                    response_serializer=dborgproto__pb2.RequestMessage.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dashborg.rpc1.DashborgService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DashborgService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Proc(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dashborg.rpc1.DashborgService/Proc',
            dborgproto__pb2.ProcMessage.SerializeToString,
            dborgproto__pb2.ProcResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendResponse(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dashborg.rpc1.DashborgService/SendResponse',
            dborgproto__pb2.SendResponseMessage.SerializeToString,
            dborgproto__pb2.SendResponseResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterHandler(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dashborg.rpc1.DashborgService/RegisterHandler',
            dborgproto__pb2.RegisterHandlerMessage.SerializeToString,
            dborgproto__pb2.RegisterHandlerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dashborg.rpc1.DashborgService/StartStream',
            dborgproto__pb2.StartStreamMessage.SerializeToString,
            dborgproto__pb2.StartStreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReflectZone(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dashborg.rpc1.DashborgService/ReflectZone',
            dborgproto__pb2.ReflectZoneMessage.SerializeToString,
            dborgproto__pb2.ReflectZoneResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CallDataHandler(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dashborg.rpc1.DashborgService/CallDataHandler',
            dborgproto__pb2.CallDataHandlerMessage.SerializeToString,
            dborgproto__pb2.CallDataHandlerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BackendPush(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dashborg.rpc1.DashborgService/BackendPush',
            dborgproto__pb2.BackendPushMessage.SerializeToString,
            dborgproto__pb2.BackendPushResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RequestStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/dashborg.rpc1.DashborgService/RequestStream',
            dborgproto__pb2.RequestStreamMessage.SerializeToString,
            dborgproto__pb2.RequestMessage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dborgproto.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='dborgproto.proto',
  package='dashborg.rpc1',
  syntax='proto3',
  serialized_options=b'Z.github.com/sawka/dashborg-go-sdk/pkg/dashproto',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10\x64\x62orgproto.proto\x12\rdashborg.rpc1\"\xb4\x01\n\x08RRAction\x12\n\n\x02Ts\x18\x01 \x01(\x03\x12\x12\n\nActionType\x18\x02 \x01(\t\x12\x10\n\x08Selector\x18\x03 \x01(\t\x12\x10\n\x08JsonData\x18\x04 \x01(\t\x12\x11\n\tEventType\x18\x05 \x01(\t\x12\x0c\n\x04Html\x18\x06 \x01(\t\x12\x0b\n\x03\x45rr\x18\x07 \x01(\t\x12\x11\n\tBlobBytes\x18\x08 \x01(\x0c\x12\x14\n\x0c\x42lobMimeType\x18\t \x01(\t\x12\r\n\x05ReqId\x18\n \x01(\t\"\xb9\x01\n\x13SendResponseMessage\x12\n\n\x02Ts\x18\x01 \x01(\x03\x12\r\n\x05ReqId\x18\x02 \x01(\t\x12\x13\n\x0bRequestType\x18\x03 \x01(\t\x12\x11\n\tPanelName\x18\x04 \x01(\t\x12\x12\n\nFeClientId\x18\x05 \x01(\t\x12\x14\n\x0cResponseDone\x18\x06 \x01(\x08\x12(\n\x07\x41\x63tions\x18\x07 \x03(\x0b\x32\x17.dashborg.rpc1.RRAction\x12\x0b\n\x03\x45rr\x18\x08 \x01(\t\"\xda\x02\n\x0eRequestMessage\x12\n\n\x02Ts\x18\x01 \x01(\x03\x12\r\n\x05\x41\x63\x63Id\x18\x02 \x01(\t\x12\x10\n\x08ZoneName\x18\x03 \x01(\t\x12\x11\n\tPanelName\x18\x04 \x01(\t\x12\x13\n\x0bRequestType\x18\x05 \x01(\t\x12\x0c\n\x04Path\x18\x06 \x01(\t\x12\r\n\x05ReqId\x18\x07 \x01(\t\x12\x12\n\nFeClientId\x18\x08 \x01(\t\x12\x11\n\tControlId\x18\t \x01(\t\x12\x10\n\x08JsonData\x18\n \x01(\t\x12\x10\n\x08\x41uthData\x18\x0b \x01(\t\x12\x16\n\x0ePanelStateData\x18\x0c \x01(\t\x12\x0b\n\x03\x45rr\x18\r \x01(\t\x12)\n\x07\x45rrCode\x18\x0e \x01(\x0e\x32\x18.dashborg.rpc1.ErrorCode\x12\x11\n\tTimeoutMs\x18\x0f \x01(\x03\x12\x11\n\tDataPaths\x18\x10 \x03(\t\x12\x15\n\rIsBackendCall\x18\x11 \x01(\x08\"B\n\nHandlerKey\x12\x11\n\tPanelName\x18\x01 \x01(\t\x12\x13\n\x0bHandlerType\x18\x02 \x01(\t\x12\x0c\n\x04Path\x18\x03 \x01(\t\"Q\n\x16RegisterHandlerMessage\x12\n\n\x02Ts\x18\x01 \x01(\x03\x12+\n\x08Handlers\x18\x02 \x03(\x0b\x32\x19.dashborg.rpc1.HandlerKey\"b\n\x17RegisterHandlerResponse\x12\x0f\n\x07Success\x18\x01 \x01(\x08\x12\x0b\n\x03\x45rr\x18\x02 \x01(\t\x12)\n\x07\x45rrCode\x18\x03 \x01(\x0e\x32\x18.dashborg.rpc1.ErrorCode\"\x9f\x03\n\x0bProcMessage\x12\n\n\x02Ts\x18\x01 \x01(\x03\x12\x11\n\tProcRunId\x18\x02 \x01(\t\x12\r\n\x05\x41\x63\x63Id\x18\x03 \x01(\t\x12\x10\n\x08ZoneName\x18\x04 \x01(\t\x12\x0f\n\x07\x41nonAcc\x18\x05 \x01(\x08\x12\x10\n\x08ProcName\x18\x06 \x01(\t\x12:\n\x08ProcTags\x18\x07 \x03(\x0b\x32(.dashborg.rpc1.ProcMessage.ProcTagsEntry\x12:\n\x08HostData\x18\x08 \x03(\x0b\x32(.dashborg.rpc1.ProcMessage.HostDataEntry\x12\x0f\n\x07StartTs\x18\t \x01(\x03\x12+\n\x08Handlers\x18\n \x03(\x0b\x32\x19.dashborg.rpc1.HandlerKey\x12\x15\n\rClientVersion\x18\x0b \x01(\t\x1a/\n\rProcTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rHostDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"g\n\x0cProcResponse\x12\x0f\n\x07Success\x18\x01 \x01(\x08\x12\x0b\n\x03\x45rr\x18\x02 \x01(\t\x12)\n\x07\x45rrCode\x18\x03 \x01(\x0e\x32\x18.dashborg.rpc1.ErrorCode\x12\x0e\n\x06\x43onnId\x18\x04 \x01(\t\"\"\n\x14RequestStreamMessage\x12\n\n\x02Ts\x18\x01 \x01(\x03\"y\n\x14SendResponseResponse\x12\x0f\n\x07Success\x18\x01 \x01(\x08\x12\x0b\n\x03\x45rr\x18\x02 \x01(\t\x12)\n\x07\x45rrCode\x18\x03 \x01(\x0e\x32\x18.dashborg.rpc1.ErrorCode\x12\x18\n\x10NumStreamClients\x18\x04 \x01(\x05\"^\n\x12StartStreamMessage\x12\n\n\x02Ts\x18\x01 \x01(\x03\x12\x11\n\tPanelName\x18\x02 \x01(\t\x12\x12\n\nFeClientId\x18\x03 \x01(\t\x12\x15\n\rExistingReqId\x18\x04 \x01(\t\"B\n\x13StartStreamResponse\x12\x0f\n\x07Success\x18\x01 \x01(\x08\x12\x0b\n\x03\x45rr\x18\x02 \x01(\t\x12\r\n\x05ReqId\x18\x03 \x01(\t\" \n\x12ReflectZoneMessage\x12\n\n\x02Ts\x18\x01 \x01(\x03\"E\n\x13ReflectZoneResponse\x12\x0f\n\x07Success\x18\x01 \x01(\x08\x12\x0b\n\x03\x45rr\x18\x02 \x01(\t\x12\x10\n\x08JsonData\x18\x03 \x01(\t\"W\n\x16\x43\x61llDataHandlerMessage\x12\n\n\x02Ts\x18\x01 \x01(\x03\x12\x11\n\tPanelName\x18\x02 \x01(\t\x12\x0c\n\x04Path\x18\x03 \x01(\t\x12\x10\n\x08JsonData\x18\x04 \x01(\t\"I\n\x17\x43\x61llDataHandlerResponse\x12\x0f\n\x07Success\x18\x01 \x01(\x08\x12\x0b\n\x03\x45rr\x18\x02 \x01(\t\x12\x10\n\x08JsonData\x18\x03 \x01(\t\"A\n\x12\x42\x61\x63kendPushMessage\x12\n\n\x02Ts\x18\x01 \x01(\x03\x12\x11\n\tPanelName\x18\x02 \x01(\t\x12\x0c\n\x04Path\x18\x03 \x01(\t\"3\n\x13\x42\x61\x63kendPushResponse\x12\x0f\n\x07Success\x18\x01 \x01(\x08\x12\x0b\n\x03\x45rr\x18\x02 \x01(\t*~\n\tErrorCode\x12\x0b\n\x07\x45\x43_NONE\x10\x00\x12\n\n\x06\x45\x43_EOF\x10\x01\x12\x0e\n\nEC_UNKNOWN\x10\x02\x12\x10\n\x0c\x45\x43_BADCONNID\x10\x03\x12\x10\n\x0c\x45\x43_ACCACCESS\x10\x04\x12\x10\n\x0c\x45\x43_NOHANDLER\x10\x05\x12\x12\n\x0e\x45\x43_UNAVAILABLE\x10\x06\x32\xd8\x05\n\x0f\x44\x61shborgService\x12\x41\n\x04Proc\x12\x1a.dashborg.rpc1.ProcMessage\x1a\x1b.dashborg.rpc1.ProcResponse\"\x00\x12Y\n\x0cSendResponse\x12\".dashborg.rpc1.SendResponseMessage\x1a#.dashborg.rpc1.SendResponseResponse\"\x00\x12\x62\n\x0fRegisterHandler\x12%.dashborg.rpc1.RegisterHandlerMessage\x1a&.dashborg.rpc1.RegisterHandlerResponse\"\x00\x12V\n\x0bStartStream\x12!.dashborg.rpc1.StartStreamMessage\x1a\".dashborg.rpc1.StartStreamResponse\"\x00\x12V\n\x0bReflectZone\x12!.dashborg.rpc1.ReflectZoneMessage\x1a\".dashborg.rpc1.ReflectZoneResponse\"\x00\x12\x62\n\x0f\x43\x61llDataHandler\x12%.dashborg.rpc1.CallDataHandlerMessage\x1a&.dashborg.rpc1.CallDataHandlerResponse\"\x00\x12V\n\x0b\x42\x61\x63kendPush\x12!.dashborg.rpc1.BackendPushMessage\x1a\".dashborg.rpc1.BackendPushResponse\"\x00\x12W\n\rRequestStream\x12#.dashborg.rpc1.RequestStreamMessage\x1a\x1d.dashborg.rpc1.RequestMessage\"\x00\x30\x01\x42\x30Z.github.com/sawka/dashborg-go-sdk/pkg/dashprotob\x06proto3'
)

_ERRORCODE = _descriptor.EnumDescriptor(
  name='ErrorCode',
  full_name='dashborg.rpc1.ErrorCode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EC_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EC_EOF', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EC_UNKNOWN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EC_BADCONNID', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EC_ACCACCESS', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EC_NOHANDLER', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EC_UNAVAILABLE', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2241,
  serialized_end=2367,
)
_sym_db.RegisterEnumDescriptor(_ERRORCODE)

ErrorCode = enum_type_wrapper.EnumTypeWrapper(_ERRORCODE)
EC_NONE = 0
EC_EOF = 1
EC_UNKNOWN = 2
EC_BADCONNID = 3
EC_ACCACCESS = 4
EC_NOHANDLER = 5
EC_UNAVAILABLE = 6



_RRACTION = _descriptor.Descriptor(
  name='RRAction',
  full_name='dashborg.rpc1.RRAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Ts', full_name='dashborg.rpc1.RRAction.Ts', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ActionType', full_name='dashborg.rpc1.RRAction.ActionType', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Selector', full_name='dashborg.rpc1.RRAction.Selector', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='JsonData', full_name='dashborg.rpc1.RRAction.JsonData', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='EventType', full_name='dashborg.rpc1.RRAction.EventType', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Html', full_name='dashborg.rpc1.RRAction.Html', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Err', full_name='dashborg.rpc1.RRAction.Err', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='BlobBytes', full_name='dashborg.rpc1.RRAction.BlobBytes', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='BlobMimeType', full_name='dashborg.rpc1.RRAction.BlobMimeType', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ReqId', full_name='dashborg.rpc1.RRAction.ReqId', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36,
  serialized_end=216,
)


_SENDRESPONSEMESSAGE = _descriptor.Descriptor(
  name='SendResponseMessage',
  full_name='dashborg.rpc1.SendResponseMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Ts', full_name='dashborg.rpc1.SendResponseMessage.Ts', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ReqId', full_name='dashborg.rpc1.SendResponseMessage.ReqId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='RequestType', full_name='dashborg.rpc1.SendResponseMessage.RequestType', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='PanelName', full_name='dashborg.rpc1.SendResponseMessage.PanelName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='FeClientId', full_name='dashborg.rpc1.SendResponseMessage.FeClientId', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ResponseDone', full_name='dashborg.rpc1.SendResponseMessage.ResponseDone', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Actions', full_name='dashborg.rpc1.SendResponseMessage.Actions', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Err', full_name='dashborg.rpc1.SendResponseMessage.Err', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=219,
  serialized_end=404,
)


_REQUESTMESSAGE = _descriptor.Descriptor(
  name='RequestMessage',
  full_name='dashborg.rpc1.RequestMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Ts', full_name='dashborg.rpc1.RequestMessage.Ts', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='AccId', full_name='dashborg.rpc1.RequestMessage.AccId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ZoneName', full_name='dashborg.rpc1.RequestMessage.ZoneName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='PanelName', full_name='dashborg.rpc1.RequestMessage.PanelName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='RequestType', full_name='dashborg.rpc1.RequestMessage.RequestType', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Path', full_name='dashborg.rpc1.RequestMessage.Path', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ReqId', full_name='dashborg.rpc1.RequestMessage.ReqId', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='FeClientId', full_name='dashborg.rpc1.RequestMessage.FeClientId', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ControlId', full_name='dashborg.rpc1.RequestMessage.ControlId', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='JsonData', full_name='dashborg.rpc1.RequestMessage.JsonData', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='AuthData', full_name='dashborg.rpc1.RequestMessage.AuthData', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='PanelStateData', full_name='dashborg.rpc1.RequestMessage.PanelStateData', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Err', full_name='dashborg.rpc1.RequestMessage.Err', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ErrCode', full_name='dashborg.rpc1.RequestMessage.ErrCode', index=13,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='TimeoutMs', full_name='dashborg.rpc1.RequestMessage.TimeoutMs', index=14,
      number=15, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='DataPaths', full_name='dashborg.rpc1.RequestMessage.DataPaths', index=15,
      number=16, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='IsBackendCall', full_name='dashborg.rpc1.RequestMessage.IsBackendCall', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=407,
  serialized_end=753,
)


_HANDLERKEY = _descriptor.Descriptor(
  name='HandlerKey',
  full_name='dashborg.rpc1.HandlerKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='PanelName', full_name='dashborg.rpc1.HandlerKey.PanelName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='HandlerType', full_name='dashborg.rpc1.HandlerKey.HandlerType', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Path', full_name='dashborg.rpc1.HandlerKey.Path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=755,
  serialized_end=821,
)


_REGISTERHANDLERMESSAGE = _descriptor.Descriptor(
  name='RegisterHandlerMessage',
  full_name='dashborg.rpc1.RegisterHandlerMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Ts', full_name='dashborg.rpc1.RegisterHandlerMessage.Ts', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Handlers', full_name='dashborg.rpc1.RegisterHandlerMessage.Handlers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=823,
  serialized_end=904,
)


_REGISTERHANDLERRESPONSE = _descriptor.Descriptor(
  name='RegisterHandlerResponse',
  full_name='dashborg.rpc1.RegisterHandlerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Success', full_name='dashborg.rpc1.RegisterHandlerResponse.Success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Err', full_name='dashborg.rpc1.RegisterHandlerResponse.Err', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ErrCode', full_name='dashborg.rpc1.RegisterHandlerResponse.ErrCode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=906,
  serialized_end=1004,
)


_PROCMESSAGE_PROCTAGSENTRY = _descriptor.Descriptor(
  name='ProcTagsEntry',
  full_name='dashborg.rpc1.ProcMessage.ProcTagsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dashborg.rpc1.ProcMessage.ProcTagsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='dashborg.rpc1.ProcMessage.ProcTagsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1326,
  serialized_end=1373,
)

_PROCMESSAGE_HOSTDATAENTRY = _descriptor.Descriptor(
  name='HostDataEntry',
  full_name='dashborg.rpc1.ProcMessage.HostDataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dashborg.rpc1.ProcMessage.HostDataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='dashborg.rpc1.ProcMessage.HostDataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1375,
  serialized_end=1422,
)

_PROCMESSAGE = _descriptor.Descriptor(
  name='ProcMessage',
  full_name='dashborg.rpc1.ProcMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Ts', full_name='dashborg.rpc1.ProcMessage.Ts', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ProcRunId', full_name='dashborg.rpc1.ProcMessage.ProcRunId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='AccId', full_name='dashborg.rpc1.ProcMessage.AccId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ZoneName', full_name='dashborg.rpc1.ProcMessage.ZoneName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='AnonAcc', full_name='dashborg.rpc1.ProcMessage.AnonAcc', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ProcName', full_name='dashborg.rpc1.ProcMessage.ProcName', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ProcTags', full_name='dashborg.rpc1.ProcMessage.ProcTags', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='HostData', full_name='dashborg.rpc1.ProcMessage.HostData', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='StartTs', full_name='dashborg.rpc1.ProcMessage.StartTs', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Handlers', full_name='dashborg.rpc1.ProcMessage.Handlers', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ClientVersion', full_name='dashborg.rpc1.ProcMessage.ClientVersion', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PROCMESSAGE_PROCTAGSENTRY, _PROCMESSAGE_HOSTDATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1007,
  serialized_end=1422,
)


_PROCRESPONSE = _descriptor.Descriptor(
  name='ProcResponse',
  full_name='dashborg.rpc1.ProcResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Success', full_name='dashborg.rpc1.ProcResponse.Success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Err', full_name='dashborg.rpc1.ProcResponse.Err', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ErrCode', full_name='dashborg.rpc1.ProcResponse.ErrCode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ConnId', full_name='dashborg.rpc1.ProcResponse.ConnId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1424,
  serialized_end=1527,
)


_REQUESTSTREAMMESSAGE = _descriptor.Descriptor(
  name='RequestStreamMessage',
  full_name='dashborg.rpc1.RequestStreamMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Ts', full_name='dashborg.rpc1.RequestStreamMessage.Ts', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1529,
  serialized_end=1563,
)


_SENDRESPONSERESPONSE = _descriptor.Descriptor(
  name='SendResponseResponse',
  full_name='dashborg.rpc1.SendResponseResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Success', full_name='dashborg.rpc1.SendResponseResponse.Success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Err', full_name='dashborg.rpc1.SendResponseResponse.Err', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ErrCode', full_name='dashborg.rpc1.SendResponseResponse.ErrCode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='NumStreamClients', full_name='dashborg.rpc1.SendResponseResponse.NumStreamClients', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1565,
  serialized_end=1686,
)


_STARTSTREAMMESSAGE = _descriptor.Descriptor(
  name='StartStreamMessage',
  full_name='dashborg.rpc1.StartStreamMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Ts', full_name='dashborg.rpc1.StartStreamMessage.Ts', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='PanelName', full_name='dashborg.rpc1.StartStreamMessage.PanelName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='FeClientId', full_name='dashborg.rpc1.StartStreamMessage.FeClientId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ExistingReqId', full_name='dashborg.rpc1.StartStreamMessage.ExistingReqId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1688,
  serialized_end=1782,
)


_STARTSTREAMRESPONSE = _descriptor.Descriptor(
  name='StartStreamResponse',
  full_name='dashborg.rpc1.StartStreamResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Success', full_name='dashborg.rpc1.StartStreamResponse.Success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Err', full_name='dashborg.rpc1.StartStreamResponse.Err', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ReqId', full_name='dashborg.rpc1.StartStreamResponse.ReqId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1784,
  serialized_end=1850,
)


_REFLECTZONEMESSAGE = _descriptor.Descriptor(
  name='ReflectZoneMessage',
  full_name='dashborg.rpc1.ReflectZoneMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Ts', full_name='dashborg.rpc1.ReflectZoneMessage.Ts', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1852,
  serialized_end=1884,
)


_REFLECTZONERESPONSE = _descriptor.Descriptor(
  name='ReflectZoneResponse',
  full_name='dashborg.rpc1.ReflectZoneResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Success', full_name='dashborg.rpc1.ReflectZoneResponse.Success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Err', full_name='dashborg.rpc1.ReflectZoneResponse.Err', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='JsonData', full_name='dashborg.rpc1.ReflectZoneResponse.JsonData', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1886,
  serialized_end=1955,
)


_CALLDATAHANDLERMESSAGE = _descriptor.Descriptor(
  name='CallDataHandlerMessage',
  full_name='dashborg.rpc1.CallDataHandlerMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Ts', full_name='dashborg.rpc1.CallDataHandlerMessage.Ts', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='PanelName', full_name='dashborg.rpc1.CallDataHandlerMessage.PanelName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Path', full_name='dashborg.rpc1.CallDataHandlerMessage.Path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='JsonData', full_name='dashborg.rpc1.CallDataHandlerMessage.JsonData', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1957,
  serialized_end=2044,
)


_CALLDATAHANDLERRESPONSE = _descriptor.Descriptor(
  name='CallDataHandlerResponse',
  full_name='dashborg.rpc1.CallDataHandlerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Success', full_name='dashborg.rpc1.CallDataHandlerResponse.Success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Err', full_name='dashborg.rpc1.CallDataHandlerResponse.Err', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='JsonData', full_name='dashborg.rpc1.CallDataHandlerResponse.JsonData', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2046,
  serialized_end=2119,
)


_BACKENDPUSHMESSAGE = _descriptor.Descriptor(
  name='BackendPushMessage',
  full_name='dashborg.rpc1.BackendPushMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Ts', full_name='dashborg.rpc1.BackendPushMessage.Ts', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='PanelName', full_name='dashborg.rpc1.BackendPushMessage.PanelName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Path', full_name='dashborg.rpc1.BackendPushMessage.Path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2121,
  serialized_end=2186,
)


_BACKENDPUSHRESPONSE = _descriptor.Descriptor(
  name='BackendPushResponse',
  full_name='dashborg.rpc1.BackendPushResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Success', full_name='dashborg.rpc1.BackendPushResponse.Success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Err', full_name='dashborg.rpc1.BackendPushResponse.Err', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2188,
  serialized_end=2239,
)

_SENDRESPONSEMESSAGE.fields_by_name['Actions'].message_type = _RRACTION
_REQUESTMESSAGE.fields_by_name['ErrCode'].enum_type = _ERRORCODE
_REGISTERHANDLERMESSAGE.fields_by_name['Handlers'].message_type = _HANDLERKEY
_REGISTERHANDLERRESPONSE.fields_by_name['ErrCode'].enum_type = _ERRORCODE
_PROCMESSAGE_PROCTAGSENTRY.containing_type = _PROCMESSAGE
_PROCMESSAGE_HOSTDATAENTRY.containing_type = _PROCMESSAGE
_PROCMESSAGE.fields_by_name['ProcTags'].message_type = _PROCMESSAGE_PROCTAGSENTRY
_PROCMESSAGE.fields_by_name['HostData'].message_type = _PROCMESSAGE_HOSTDATAENTRY
_PROCMESSAGE.fields_by_name['Handlers'].message_type = _HANDLERKEY
_PROCRESPONSE.fields_by_name['ErrCode'].enum_type = _ERRORCODE
_SENDRESPONSERESPONSE.fields_by_name['ErrCode'].enum_type = _ERRORCODE
DESCRIPTOR.message_types_by_name['RRAction'] = _RRACTION
DESCRIPTOR.message_types_by_name['SendResponseMessage'] = _SENDRESPONSEMESSAGE
DESCRIPTOR.message_types_by_name['RequestMessage'] = _REQUESTMESSAGE
DESCRIPTOR.message_types_by_name['HandlerKey'] = _HANDLERKEY
DESCRIPTOR.message_types_by_name['RegisterHandlerMessage'] = _REGISTERHANDLERMESSAGE
DESCRIPTOR.message_types_by_name['RegisterHandlerResponse'] = _REGISTERHANDLERRESPONSE
DESCRIPTOR.message_types_by_name['ProcMessage'] = _PROCMESSAGE
DESCRIPTOR.message_types_by_name['ProcResponse'] = _PROCRESPONSE
DESCRIPTOR.message_types_by_name['RequestStreamMessage'] = _REQUESTSTREAMMESSAGE
DESCRIPTOR.message_types_by_name['SendResponseResponse'] = _SENDRESPONSERESPONSE
DESCRIPTOR.message_types_by_name['StartStreamMessage'] = _STARTSTREAMMESSAGE
DESCRIPTOR.message_types_by_name['StartStreamResponse'] = _STARTSTREAMRESPONSE
DESCRIPTOR.message_types_by_name['ReflectZoneMessage'] = _REFLECTZONEMESSAGE
DESCRIPTOR.message_types_by_name['ReflectZoneResponse'] = _REFLECTZONERESPONSE
DESCRIPTOR.message_types_by_name['CallDataHandlerMessage'] = _CALLDATAHANDLERMESSAGE
DESCRIPTOR.message_types_by_name['CallDataHandlerResponse'] = _CALLDATAHANDLERRESPONSE
DESCRIPTOR.message_types_by_name['BackendPushMessage'] = _BACKENDPUSHMESSAGE
DESCRIPTOR.message_types_by_name['BackendPushResponse'] = _BACKENDPUSHRESPONSE
DESCRIPTOR.enum_types_by_name['ErrorCode'] = _ERRORCODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RRAction = _reflection.GeneratedProtocolMessageType('RRAction', (_message.Message,), {
  'DESCRIPTOR' : _RRACTION,
  '__module__' : 'dborgproto_pb2'
  # @@protoc_insertion_point(class_scope:dashborg.rpc1.RRAction)
  })
_sym_db.RegisterMessage(RRAction)

SendResponseMessage = _reflection.GeneratedProtocolMessageType('SendResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _SENDRESPONSEMESSAGE,
  '__module__' : 'dborgproto_pb2'
  # @@protoc_insertion_point(class_scope:dashborg.rpc1.SendResponseMessage)
  })
_sym_db.RegisterMessage(SendResponseMessage)

RequestMessage = _reflection.GeneratedProtocolMessageType('RequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTMESSAGE,
  '__module__' : 'dborgproto_pb2'
  # @@protoc_insertion_point(class_scope:dashborg.rpc1.RequestMessage)
  })
_sym_db.RegisterMessage(RequestMessage)

HandlerKey = _reflection.GeneratedProtocolMessageType('HandlerKey', (_message.Message,), {
  'DESCRIPTOR' : _HANDLERKEY,
  '__module__' : 'dborgproto_pb2'
  # @@protoc_insertion_point(class_scope:dashborg.rpc1.HandlerKey)
  })
_sym_db.RegisterMessage(HandlerKey)

RegisterHandlerMessage = _reflection.GeneratedProtocolMessageType('RegisterHandlerMessage', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERHANDLERMESSAGE,
  '__module__' : 'dborgproto_pb2'
  # @@protoc_insertion_point(class_scope:dashborg.rpc1.RegisterHandlerMessage)
  })
_sym_db.RegisterMessage(RegisterHandlerMessage)

RegisterHandlerResponse = _reflection.GeneratedProtocolMessageType('RegisterHandlerResponse', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERHANDLERRESPONSE,
  '__module__' : 'dborgproto_pb2'
  # @@protoc_insertion_point(class_scope:dashborg.rpc1.RegisterHandlerResponse)
  })
_sym_db.RegisterMessage(RegisterHandlerResponse)

ProcMessage = _reflection.GeneratedProtocolMessageType('ProcMessage', (_message.Message,), {

  'ProcTagsEntry' : _reflection.GeneratedProtocolMessageType('ProcTagsEntry', (_message.Message,), {
    'DESCRIPTOR' : _PROCMESSAGE_PROCTAGSENTRY,
    '__module__' : 'dborgproto_pb2'
    # @@protoc_insertion_point(class_scope:dashborg.rpc1.ProcMessage.ProcTagsEntry)
    })
  ,

  'HostDataEntry' : _reflection.GeneratedProtocolMessageType('HostDataEntry', (_message.Message,), {
    'DESCRIPTOR' : _PROCMESSAGE_HOSTDATAENTRY,
    '__module__' : 'dborgproto_pb2'
    # @@protoc_insertion_point(class_scope:dashborg.rpc1.ProcMessage.HostDataEntry)
    })
  ,
  'DESCRIPTOR' : _PROCMESSAGE,
  '__module__' : 'dborgproto_pb2'
  # @@protoc_insertion_point(class_scope:dashborg.rpc1.ProcMessage)
  })
_sym_db.RegisterMessage(ProcMessage)
_sym_db.RegisterMessage(ProcMessage.ProcTagsEntry)
_sym_db.RegisterMessage(ProcMessage.HostDataEntry)

ProcResponse = _reflection.GeneratedProtocolMessageType('ProcResponse', (_message.Message,), {
  'DESCRIPTOR' : _PROCRESPONSE,
  '__module__' : 'dborgproto_pb2'
  # @@protoc_insertion_point(class_scope:dashborg.rpc1.ProcResponse)
  })
_sym_db.RegisterMessage(ProcResponse)

RequestStreamMessage = _reflection.GeneratedProtocolMessageType('RequestStreamMessage', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTSTREAMMESSAGE,
  '__module__' : 'dborgproto_pb2'
  # @@protoc_insertion_point(class_scope:dashborg.rpc1.RequestStreamMessage)
  })
_sym_db.RegisterMessage(RequestStreamMessage)

SendResponseResponse = _reflection.GeneratedProtocolMessageType('SendResponseResponse', (_message.Message,), {
  'DESCRIPTOR' : _SENDRESPONSERESPONSE,
  '__module__' : 'dborgproto_pb2'
  # @@protoc_insertion_point(class_scope:dashborg.rpc1.SendResponseResponse)
  })
_sym_db.RegisterMessage(SendResponseResponse)

StartStreamMessage = _reflection.GeneratedProtocolMessageType('StartStreamMessage', (_message.Message,), {
  'DESCRIPTOR' : _STARTSTREAMMESSAGE,
  '__module__' : 'dborgproto_pb2'
  # @@protoc_insertion_point(class_scope:dashborg.rpc1.StartStreamMessage)
  })
_sym_db.RegisterMessage(StartStreamMessage)

StartStreamResponse = _reflection.GeneratedProtocolMessageType('StartStreamResponse', (_message.Message,), {
  'DESCRIPTOR' : _STARTSTREAMRESPONSE,
  '__module__' : 'dborgproto_pb2'
  # @@protoc_insertion_point(class_scope:dashborg.rpc1.StartStreamResponse)
  })
_sym_db.RegisterMessage(StartStreamResponse)

ReflectZoneMessage = _reflection.GeneratedProtocolMessageType('ReflectZoneMessage', (_message.Message,), {
  'DESCRIPTOR' : _REFLECTZONEMESSAGE,
  '__module__' : 'dborgproto_pb2'
  # @@protoc_insertion_point(class_scope:dashborg.rpc1.ReflectZoneMessage)
  })
_sym_db.RegisterMessage(ReflectZoneMessage)

ReflectZoneResponse = _reflection.GeneratedProtocolMessageType('ReflectZoneResponse', (_message.Message,), {
  'DESCRIPTOR' : _REFLECTZONERESPONSE,
  '__module__' : 'dborgproto_pb2'
  # @@protoc_insertion_point(class_scope:dashborg.rpc1.ReflectZoneResponse)
  })
_sym_db.RegisterMessage(ReflectZoneResponse)

CallDataHandlerMessage = _reflection.GeneratedProtocolMessageType('CallDataHandlerMessage', (_message.Message,), {
  'DESCRIPTOR' : _CALLDATAHANDLERMESSAGE,
  '__module__' : 'dborgproto_pb2'
  # @@protoc_insertion_point(class_scope:dashborg.rpc1.CallDataHandlerMessage)
  })
_sym_db.RegisterMessage(CallDataHandlerMessage)

CallDataHandlerResponse = _reflection.GeneratedProtocolMessageType('CallDataHandlerResponse', (_message.Message,), {
  'DESCRIPTOR' : _CALLDATAHANDLERRESPONSE,
  '__module__' : 'dborgproto_pb2'
  # @@protoc_insertion_point(class_scope:dashborg.rpc1.CallDataHandlerResponse)
  })
_sym_db.RegisterMessage(CallDataHandlerResponse)

BackendPushMessage = _reflection.GeneratedProtocolMessageType('BackendPushMessage', (_message.Message,), {
  'DESCRIPTOR' : _BACKENDPUSHMESSAGE,
  '__module__' : 'dborgproto_pb2'
  # @@protoc_insertion_point(class_scope:dashborg.rpc1.BackendPushMessage)
  })
_sym_db.RegisterMessage(BackendPushMessage)

BackendPushResponse = _reflection.GeneratedProtocolMessageType('BackendPushResponse', (_message.Message,), {
  'DESCRIPTOR' : _BACKENDPUSHRESPONSE,
  '__module__' : 'dborgproto_pb2'
  # @@protoc_insertion_point(class_scope:dashborg.rpc1.BackendPushResponse)
  })
_sym_db.RegisterMessage(BackendPushResponse)


DESCRIPTOR._options = None
_PROCMESSAGE_PROCTAGSENTRY._options = None
_PROCMESSAGE_HOSTDATAENTRY._options = None

_DASHBORGSERVICE = _descriptor.ServiceDescriptor(
  name='DashborgService',
  full_name='dashborg.rpc1.DashborgService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2370,
  serialized_end=3098,
  methods=[
  _descriptor.MethodDescriptor(
    name='Proc',
    full_name='dashborg.rpc1.DashborgService.Proc',
    index=0,
    containing_service=None,
    input_type=_PROCMESSAGE,
    output_type=_PROCRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendResponse',
    full_name='dashborg.rpc1.DashborgService.SendResponse',
    index=1,
    containing_service=None,
    input_type=_SENDRESPONSEMESSAGE,
    output_type=_SENDRESPONSERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RegisterHandler',
    full_name='dashborg.rpc1.DashborgService.RegisterHandler',
    index=2,
    containing_service=None,
    input_type=_REGISTERHANDLERMESSAGE,
    output_type=_REGISTERHANDLERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StartStream',
    full_name='dashborg.rpc1.DashborgService.StartStream',
    index=3,
    containing_service=None,
    input_type=_STARTSTREAMMESSAGE,
    output_type=_STARTSTREAMRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReflectZone',
    full_name='dashborg.rpc1.DashborgService.ReflectZone',
    index=4,
    containing_service=None,
    input_type=_REFLECTZONEMESSAGE,
    output_type=_REFLECTZONERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CallDataHandler',
    full_name='dashborg.rpc1.DashborgService.CallDataHandler',
    index=5,
    containing_service=None,
    input_type=_CALLDATAHANDLERMESSAGE,
    output_type=_CALLDATAHANDLERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BackendPush',
    full_name='dashborg.rpc1.DashborgService.BackendPush',
    index=6,
    containing_service=None,
    input_type=_BACKENDPUSHMESSAGE,
    output_type=_BACKENDPUSHRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RequestStream',
    full_name='dashborg.rpc1.DashborgService.RequestStream',
    index=7,
    containing_service=None,
    input_type=_REQUESTSTREAMMESSAGE,
    output_type=_REQUESTMESSAGE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DASHBORGSERVICE)

DESCRIPTOR.services_by_name['DashborgService'] = _DASHBORGSERVICE

# @@protoc_insertion_point(module_scope)



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="dashborg-python-sdk",
    version="0.3.1.dev1",
    author="Michael Sawka",
    author_email="mike@dashborg.net",
    description="Dashborg Python SDK",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/sawka/dashborg-python-sdk",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        'aiofiles',
        'cffi',
        'cryptography',
        'ecdsa',
        'grpcio',
        'grpcio-tools',
        'protobuf',
        'pycparser',
        'six',
        'pyjwt',
    ],
    python_requires='>=3.6',
)
